aboutsummaryrefslogtreecommitdiff
path: root/webui-user.sh
diff options
context:
space:
mode:
Diffstat (limited to 'webui-user.sh')
-rw-r--r--webui-user.sh25
1 files changed, 16 insertions, 9 deletions
diff --git a/webui-user.sh b/webui-user.sh
index d4b8727a..36166df9 100644
--- a/webui-user.sh
+++ b/webui-user.sh
@@ -9,25 +9,32 @@ install_dir="/home/$(whoami)"
# Name of the subdirectory (defaults to stable-diffusion-webui)
clone_dir="stable-diffusion-webui"
-# Commandline arguments for webui.py, for example: commandline_args=(--medvram --opt-split-attention)
-commandline_args=()
+# Commandline arguments for webui.py, for example: export COMMANDLINE_ARGS=(--medvram --opt-split-attention)
+export COMMANDLINE_ARGS=()
# python3 executable
python_cmd="python3"
-# pip3 executable
-pip_cmd=(python3 -m pip)
-
# git executable
-git_cmd="git"
+export GIT=""
# python3 venv without trailing slash (defaults to ${install_dir}/${clone_dir}/venv)
venv_dir="venv"
-# pip3 install command for torch
-torch_command=(torch==1.12.1+cu113 --extra-index-url https://download.pytorch.org/whl/cu113)
+# install command for torch
+export TORCH_COMMAND=(python3 -m pip install torch==1.12.1+cu113 --extra-index-url https://download.pytorch.org/whl/cu113)
# Requirements file to use for stable-diffusion-webui
-reqs_file="requirements_versions.txt"
+export REQS_FILE=""
+
+# Fixed git repos
+export K_DIFFUSION_PACKAGE=""
+export GFPGAN_PACKAGE=""
+
+# Fixed git commits
+export STABLE_DIFFUSION_COMMIT_HASH=""
+export TAMING_TRANSFORMERS_COMMIT_HASH=""
+export CODEFORMER_COMMIT_HASH=""
+export BLIP_COMMIT_HASH=""
########################################### \ No newline at end of file